<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Filtriloj de bild- kaj kolor-transformo',
	'images_slogan' => 'Filtriloj de bild- kaj kolor-transformo',
];
